/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2019 Vedran Grgo Vatavuk
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package hr.com.vgv.verano.http;

/**
 * Key-value pair.
 * @since 1.0
 */
public interface Kvp {

    /**
     * Key.
     * @return Key
     */
    String key();

    /**
     * Value.
     * @return Value
     */
    String value();

    /**
     * Simple implementation of {@link Kvp} used to simplify Kvp decorators.
     */
    class Envelope implements Kvp {

        /**
         * Original key-value pair.
         */
        private final Kvp origin;

        /**
         * Ctor.
         * @param origin Origin
         */
        public Envelope(final Kvp origin) {
            this.origin = origin;
        }

        @Override
        public final String key() {
            return this.origin.key();
        }

        @Override
        public final String value() {
            return this.origin.value();
        }
    }
}
